@@ -12,6 +12,7 @@ from .data_model import OutputMedium
 from .exec_core import SimulatorValidator
 from .results.data_model import TestCaseResult, TestCaseResultType, TestResultsReport  # noqa: F401
 from .results.io import write_test_results
+from .utils import get_singularity_image_filename
 from biosimulators_utils.biosimulations.utils import validate_biosimulations_api_response
 from biosimulators_utils.config import Colors
 from biosimulators_utils.gh_action.data_model import Comment, GitHubActionCaughtError  # noqa: F401
@@ -48,9 +49,9 @@ def get_uncaught_exception_msg(exception):
         Comment(text='The validation/submission of your simulator failed.'),
         Comment(text=str(exception), error=True),
         Comment(text=('The complete log of your validation/submission job, including further information about the failure, '
-                      + 'is available [here]({}).'.format(gh_action_run_url))),
+                      + 'is available for 90 days [here]({}).'.format(gh_action_run_url))),
         Comment(text=('If you chose to validate your Docker image, the results of the validation of your image will be '
-                      'available shortly as a JSON file. A link to this file will be available from the "Artifacts" '
+                      'available shortly as a JSON file. A link to this file will be available for 90 days from the "Artifacts" '
                       'section at the bottom of [this page]({}).'.format(gh_action_run_url))),
         Comment(text='Once you have fixed the problem, edit the first block of this issue to re-initiate this validation.'),
         Comment(text=('The BioSimulators Team is happy to help. '
@@ -147,8 +148,8 @@ class ValidateCommitSimulatorGitHubAction(GitHubAction):
         if submission.validate_image:
             actions.append('validating your Docker image')
             test_results_msg = (
-                ' The results of the validation of your tool will also be saved as a JSON file.'
-                'A link to this file will be available from the "Artifacts" section at the bottom of this page.'
+                ' The results of the validation of your tool will also be saved as a JSON file. '
+                'A link to this file will be available for 90 days from the "Artifacts" section at the bottom of this page.'
             )
         else:
             not_actions.append('You have chosen not to have the Docker image for your simulator validated.')
@@ -163,13 +164,13 @@ class ValidateCommitSimulatorGitHubAction(GitHubAction):
         if len(actions) == 1:
             actions = actions[0]
         else:
-            actions = ', '.join(actions[0:-1]) + ' and ' + actions[-1]
+            actions = ', '.join(actions[0:-1]) + ', and ' + actions[-1]
         not_actions = ' '.join(action.strip() for action in not_actions)
 
         return ('Thank you @{} for your submission to the BioSimulators simulator validation/submission system!\n\n'
                 'The BioSimulators validator bot is {}. {}\n\n'
                 'We will discuss any concerns with your submission in this issue.\n\n'
-                'A complete log of your simulator {} job will be available [here]({}).{}\n\n'
+                'A complete log of your simulator {} job will be available for 90 days [here]({}).{}\n\n'
                 ).format(submitter, actions, not_actions, job_type, self.get_gh_action_run_url(), test_results_msg)
 
     def exec_core(self, submission, submitter):
@@ -190,7 +191,8 @@ class ValidateCommitSimulatorGitHubAction(GitHubAction):
         """
         # validate specifications
         specifications = biosimulators_utils.simulator.io.read_simulator_specs(
-            submission.specifications_url, submission.specifications_patch)
+            submission.specifications_url, submission.specifications_patch,
+            validate=True)
 
         # check permissions
         self.validate_permissions(specifications['id'], specifications['name'], submitter)
@@ -295,7 +297,9 @@ class ValidateCommitSimulatorGitHubAction(GitHubAction):
         get_docker_image(docker_client, image_url, pull=True)
 
         # validate that Docker image can be converted to a Singularity image
-        biosimulators_utils.image.convert_docker_image_to_singularity(image_url)
+        biosimulators_utils.image.convert_docker_image_to_singularity(
+            image_url,
+            singularity_filename=get_singularity_image_filename(image_url))
 
         # validate that image is consistent with the BioSimulators standards
         validator = SimulatorValidator(specifications, output_medium=OutputMedium.gh_issue)
@@ -357,7 +361,7 @@ class ValidateCommitSimulatorGitHubAction(GitHubAction):
             error_msg = (
                 'After correcting your simulator, please edit the first block of this issue to re-initiate this validation.\n\n'
                 'The complete log of your validation/submission job, including further information about the failure, '
-                'is available [here]({}). The results of the validation of your image will also be '
+                'is available for 90 days [here]({}). The results of the validation of your image will also be '
                 'available shortly as a JSON file. A link to this file will be available from the "Artifacts" '
                 'section at the bottom of [this page]({}).'
             ).format(gh_action_run_url, gh_action_run_url)
