@@ -12,6 +12,7 @@ from biosimulators_utils.combine.data_model import CombineArchive  # noqa: F401
 from biosimulators_utils.report.data_model import ReportFormat
 from biosimulators_utils.report.io import ReportReader
 from biosimulators_utils.sedml.data_model import SedDocument, Report  # noqa: F401
+import h5py
 import os
 import numpy
 import warnings
@@ -49,7 +50,10 @@ class SimulatorGeneratesReportsOfSimulationResults(SingleMasterSedDocumentCombin
             doc_id = os.path.relpath(doc_location, '.')
             for output in sed_doc.outputs:
                 if isinstance(output, Report):
-                    report_data = ReportReader().run(output, outputs_dir, os.path.join(doc_id, output.id), format=ReportFormat.h5)
+                    uri = os.path.join(doc_id, output.id)
+                    uri_parts = uri.split(os.path.sep)
+                    uri = '/'.join(uri_parts)
+                    report_data = ReportReader().run(output, outputs_dir, uri, format=ReportFormat.h5)
 
                     expected_data_sets = set(data_set.id for data_set in output.data_sets)
                     data_sets = set(report_data.keys())
@@ -66,4 +70,21 @@ class SimulatorGeneratesReportsOfSimulationResults(SingleMasterSedDocumentCombin
                             warnings.warn('The results produced by the simulator include `NaN`.', TestCaseWarning)
                             has_warning = True
 
+                    with h5py.File(os.path.join(outputs_dir, 'reports.h5'), 'r') as file:
+
+                        temp = file[uri].attrs.get('uri', None)
+                        if temp != uri:
+                            raise ValueError('`uri` of HDF5 data set `{}` must be `{}`, not `{}`.'.format(uri, uri, temp))
+
+                        for i_group in range(len(uri_parts) - 1):
+                            group_uri = '/'.join(uri_parts[0:i_group + 1])
+                            temp = file[group_uri].attrs.get('uri', None)
+                            if temp != group_uri:
+                                raise ValueError('`uri` of HDF5 group `{}` must be `{}`, not `{}`.'.format(group_uri, group_uri, temp))
+
+                            temp = file[group_uri].attrs.get('combineArchiveLocation', None)
+                            if temp != group_uri:
+                                raise ValueError('`combineArchiveLocation` of HDF5 group `{}` must be `{}`, not `{}`.'.format(
+                                    group_uri, group_uri, temp))
+
         return not has_warning
